@@ -59,7 +59,9 @@ void KRunUnitTest::initTestCase()
 
 void KRunUnitTest::cleanupTestCase()
 {
-    std::for_each(m_filesToRemove.begin(), m_filesToRemove.end(), [](const QString &f) { QFile::remove(f); });
+    std::for_each(m_filesToRemove.begin(), m_filesToRemove.end(), [](const QString & f) {
+        QFile::remove(f);
+    });
 }
 
 void KRunUnitTest::testBinaryName_data()
@@ -125,10 +127,10 @@ static void checkDesktopExecParser(const char *exec, const char *term, const cha
 void KRunUnitTest::testProcessDesktopExec()
 {
     QList<QUrl> l0;
-    static const char* const execs[] = { "Exec=date -u", "Exec=echo $PWD" };
-    static const char* const terms[] = { "Terminal=false", "Terminal=true\nTerminalOptions=-T \"%f - %c\"" };
-    static const char* const sus[] = { "X-KDE-SubstituteUID=false", "X-KDE-SubstituteUID=true\nX-KDE-Username=sprallo" };
-    static const char* const results[] = {
+    static const char *const execs[] = { "Exec=date -u", "Exec=echo $PWD" };
+    static const char *const terms[] = { "Terminal=false", "Terminal=true\nTerminalOptions=-T \"%f - %c\"" };
+    static const char *const sus[] = { "X-KDE-SubstituteUID=false", "X-KDE-SubstituteUID=true\nX-KDE-Username=sprallo" };
+    static const char *const results[] = {
         "/bin/date -u", // 0
         "/bin/sh -c 'echo $PWD '", // 1
         "x-term -T ' - just_a_test' -e /bin/date -u", // 2
@@ -235,10 +237,9 @@ class KRunImpl : public KRun
 {
 public:
     KRunImpl(const QUrl &url)
-        : KRun(url, 0, false), m_errCode(-1) {}
+        : KRun(url, nullptr, false), m_errCode(-1) {}
 
-    void foundMimeType(const QString &type) Q_DECL_OVERRIDE
-    {
+    void foundMimeType(const QString &type) Q_DECL_OVERRIDE {
         m_mimeType = type;
         // don't call KRun::foundMimeType, we don't want to start an app ;-)
         setFinished(true);
@@ -328,13 +329,17 @@ static void createSrcFile(const QString path)
 void KRunUnitTest::KRunRunService_data()
 {
     QTest::addColumn<bool>("tempFile");
+    QTest::addColumn<bool>("useRunApplication");
 
-    QTest::newRow("standard") << false;
-    QTest::newRow("tempfile") << true;
+    QTest::newRow("standard") << false << false;
+    QTest::newRow("tempfile") << true << false;
+    QTest::newRow("runApp") << false << true;
+    QTest::newRow("runApp_tempfile") << true << true;
 }
 void KRunUnitTest::KRunRunService()
 {
     QFETCH(bool, tempFile);
+    QFETCH(bool, useRunApplication);
 
     // Given a service desktop file and a source file
     const QString path = createTempService();
@@ -349,8 +354,10 @@ void KRunUnitTest::KRunRunService()
     QList<QUrl> urls;
     urls.append(QUrl::fromLocalFile(srcFile));
 
-    // When calling KRun::runService
-    qint64 pid = KRun::runService(service, urls, 0, tempFile);
+    // When calling KRun::runService or KRun::runApplication
+    qint64 pid = useRunApplication
+        ? KRun::runApplication(service, urls, nullptr, tempFile ? KRun::RunFlags(KRun::DeleteTemporaryFiles) : KRun::RunFlags())
+        : KRun::runService(service, urls, nullptr, tempFile);
 
     // Then the service should be executed (which copies the source file to "dest")
     QVERIFY(pid != 0);
